@@ -18,6 +18,7 @@
 #include <stdarg.h> // skipped
 #include <float.h> // skipped
 #include <errno.h> // skipped
+#include <ctype.h> // skipped
 
 // Determine if we are on a 64-bit or 32-bit architecture.
 #if defined(_M_X64) || defined(__x86_64) || defined(__aarch64__) || \
@@ -75,6 +76,10 @@
 #include <time.h> // skipped
 #endif
 
+// POSIX threads are unconditionally required, regardless of whether
+// multithreading is enabled via pthreads or OpenMP (or disabled).
+#include <pthread.h> // skipped
+
 
 #endif
 // end bli_system.h
@@ -1106,151 +1111,9 @@ typedef struct
 } pool_t;
 
 
-// -- Mutex object type --
-
-// begin bli_mutex.h
-
-
-#ifndef BLIS_MUTEX_H
-#define BLIS_MUTEX_H
-
-// Include definitions (mostly mtx_t) specific to the method of
-// multithreading.
-// begin bli_mutex_single.h
-
-
-#ifndef BLIS_MUTEX_SINGLE_H
-#define BLIS_MUTEX_SINGLE_H
-
-// Define mtx_t for situations when multithreading is disabled.
-#ifndef BLIS_ENABLE_MULTITHREADING
-
-// Define mtx_t.
-
-typedef struct mtx_s
-{
-} mtx_t;
-
-// Define macros to operate on pthread-based mtx_t.
-
-static void bli_mutex_init( mtx_t* m )
-{
-}
-
-static void bli_mutex_finalize( mtx_t* m )
-{
-}
-
-static void bli_mutex_lock( mtx_t* m )
-{
-}
-
-static void bli_mutex_unlock( mtx_t* m )
-{
-}
-
-#endif
-
-#endif
-
-// end bli_mutex_single.h
-// begin bli_mutex_openmp.h
-
-
-#ifndef BLIS_MUTEX_OPENMP_H
-#define BLIS_MUTEX_OPENMP_H
-
-// Define mutex_t for situations when OpenMP multithreading is enabled.
-#ifdef BLIS_ENABLE_OPENMP
-
-#include <omp.h> // skipped
-
-// Define mtx_t.
-
-typedef struct mtx_s
-{
-	omp_lock_t mutex;
-} mtx_t;
-
-// Define functions to operate on OpenMP-based mtx_t.
-
-static void bli_mutex_init( mtx_t* m )
-{
-	omp_init_lock( &(m->mutex) );
-}
-
-static void bli_mutex_finalize( mtx_t* m )
-{
-	omp_destroy_lock( &(m->mutex) );
-}
-
-static void bli_mutex_lock( mtx_t* m )
-{
-	omp_set_lock( &(m->mutex) );
-}
-
-static void bli_mutex_unlock( mtx_t* m )
-{
-	omp_unset_lock( &(m->mutex) );
-}
-
-#endif
-
-#endif
-
-// end bli_mutex_openmp.h
-// begin bli_mutex_pthreads.h
-
-
-#ifndef BLIS_MUTEX_PTHREADS_H
-#define BLIS_MUTEX_PTHREADS_H
-
-// Define mutex_t for situations when POSIX multithreading is enabled.
-#ifdef BLIS_ENABLE_PTHREADS
+// -- Memory broker object type --
 
 #include <pthread.h> // skipped
-
-// Define mtx_t.
-
-typedef struct mtx_s
-{
-	pthread_mutex_t mutex;
-} mtx_t;
-
-// Define macros to operate on pthread-based mtx_t.
-
-static void bli_mutex_init( mtx_t* m )
-{
-	pthread_mutex_init( &(m->mutex), NULL ); \
-}
-
-static void bli_mutex_finalize( mtx_t* m )
-{
-	pthread_mutex_destroy( &(m->mutex) ); \
-}
-
-static void bli_mutex_lock( mtx_t* m )
-{
-	pthread_mutex_lock( &(m->mutex) ); \
-}
-
-static void bli_mutex_unlock( mtx_t* m )
-{
-	pthread_mutex_unlock( &(m->mutex) ); \
-}
-
-#endif
-
-#endif
-
-// end bli_mutex_pthreads.h
-
-// Thread mutex prototypes.
-
-
-#endif
-
-// end bli_mutex.h
 // begin bli_malloc.h
 
 
@@ -1282,16 +1145,13 @@ void  bli_malloc_align_check( malloc_ft f, size_t size, size_t align_size );
 
 // end bli_malloc.h
 
-
-// -- Memory broker object type --
-
 typedef struct membrk_s
 {
-	pool_t    pools[3];
-	mtx_t     mutex;
+	pool_t          pools[3];
+	pthread_mutex_t mutex;
 
-	malloc_ft malloc_fp;
-	free_ft   free_fp;
+	malloc_ft       malloc_fp;
+	free_ft         free_fp;
 } membrk_t;
 
 
